@@ -58,38 +58,34 @@ class BaseDatasetJson(BaseModel):
     ] = Field(default_factory=dict)
 
     @root_validator(pre=False)
-    def check_dimensions_labels_keys(cls, values):  # noqa: N805
-        """Check that dimensions_codes_order and dimensions_labels keys match.
+    def check_dimensions_labels_keys(cls, values):
+        """Validate the keys of the `dimensions_labels` attribute.
 
-        This check is done only if dimensions_codes_order is defined.
+        Check that every key of `dimensions_labels` is defined in `dimensions_codes_order`, if it's defined.
         """
-        dimensions_codes_order = values.get("dimensions_codes_order")
-        if dimensions_codes_order is None:
-            return values
-        dimensions_codes_order = set(dimensions_codes_order)
-        dimensions_labels_keys = set(values["dimensions_labels"].keys())
-        if dimensions_codes_order != dimensions_labels_keys:
-            raise ValueError(
-                f"{dimensions_codes_order=} "
-                f"and the keys of dimensions_labels {dimensions_labels_keys!r} do not match"
-            )
+        cls._check_extra_keys_versus_dimensions_codes_order(values, attribute_name="dimensions_labels")
         return values
 
     @root_validator(pre=False)
-    def check_dimensions_values_labels_keys(cls, values):  # noqa: N805
-        """Check that dimensions_codes_order and dimensions_values_labels keys match.
+    def check_dimensions_values_labels_keys(cls, values):
+        """Validate the keys of the `dimensions_values_labels` attribute.
 
-        This check is done only if dimensions_codes_order is defined.
+        Check that every key of `dimensions_values_labels` is defined in `dimensions_codes_order`, if it's defined.
         """
+        cls._check_extra_keys_versus_dimensions_codes_order(values, attribute_name="dimensions_values_labels")
+        return values
+
+    @classmethod
+    def _check_extra_keys_versus_dimensions_codes_order(cls, values, *, attribute_name: str):
         dimensions_codes_order = values.get("dimensions_codes_order")
         if dimensions_codes_order is None:
             return values
         dimensions_codes_order = set(dimensions_codes_order)
-        dimensions_values_labels_keys = set(values["dimensions_values_labels"].keys())
-        if dimensions_codes_order != dimensions_values_labels_keys:
+        keys = set(values[attribute_name].keys())
+        extra_keys = keys - dimensions_codes_order
+        if extra_keys:
             raise ValueError(
-                f"dimensions_codes_order {dimensions_codes_order!r} "
-                f"and dimensions_values_labels keys {dimensions_values_labels_keys!r} do not match"
+                f"The keys {extra_keys!r} are defined in {attribute_name!r} but not in {dimensions_codes_order=}"
             )
         return values
 
